| Title: | Location Identify Tool |
|---|---|
| Description: | Determine the sea area where the fishing boat operates. The latitude and longitude of geographic coordinates are used to match oceanic areas and economic sea areas. You can plot the distribution map with dotplot() function. Please refer to Flanders Marine Institute (2020) <doi:10.14284/403>. |
| Authors: | shiao chih hao [aut, cre, ctb], chang shu ting [aut, ctb], wang shyh jiun [aut, ctb] |
| Maintainer: | shiao chih hao <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.9 |
| Built: | 2026-05-21 09:51:59 UTC |
| Source: | https://github.com/cran/oceanic |
This function allows you to draw data distribution geographically from a numeric vector.
dotplot( lona, lata, map = "ALL", grid = FALSE, color = "#FF0000", size = 1, shape = 16 )dotplot( lona, lata, map = "ALL", grid = FALSE, color = "#FF0000", size = 1, shape = 16 )
lona |
Input the longitude. |
lata |
Input the latitude. |
map |
default is "ALL", Other possible options is "PAC", "IND" and "ATL". |
grid |
default is FALSE, when TRUE show the 5 degree grid. |
color |
default is "#FF0000", define the color of points. |
size |
default is 1, define the size of points. |
shape |
default is 16, define the shape of points. |
the plot of lona and lata.
dotplot(141,23)dotplot(141,23)
A spatial dataset containing the boundaries of Exclusive Economic Zones.
eez_rgeez_rg
eez_rg is an sf object with 16 variables:
Internal identifier
Name of the EEZ area
Country name
Identifier
Sovereign state
Additional remarks
Sovereign ID
EEZ ID
ISO 3-digit country code
Marine Regions Gazetteer Identifier
Date of change
Area in square meters
Longitude of centroid
Latitude of centroid
EEZ MRGID
Spatial geometry
Flanders Marine Institute (2020). MarineRegions.org. <doi:10.14284/403>
This function allows you to identify location in which EEZ from a numeric vector.
idfeez(lon, lat, ac = TRUE)idfeez(lon, lat, ac = TRUE)
lon |
A numeric vector of longitudes. |
lat |
A numeric vector of latitudes. |
ac |
logical. If |
idfeez(141,23)idfeez(141,23)
Return The Pacific Ocean(PAC), Indian Ocean(IND) or Atlantic Ocean(ATL) of your coordinate.
idfocean(lon, lat)idfocean(lon, lat)
lon |
A numeric vector of longitudes. |
lat |
A numeric vector of latitudes. |
A character vector of the ocean ("PAC", "IND", "ATL", or "-") for each coordinate.
idfocean(125,20) idfocean(c(125, 40), c(20, -10))idfocean(125,20) idfocean(c(125, 40), c(20, -10))