| Type: | Package |
| Title: | Location Identify Tool |
| Version: | 0.1.9 |
| Date: | 2026-04-21 |
| Author: | shiao chih hao [aut, cre, ctb], chang shu ting [aut, ctb], wang shyh jiun [aut, ctb] |
| Maintainer: | shiao chih hao <chihhao@ofdc.org.tw> |
| Description: | Determine the sea area where the fishing boat operates. The latitude and longitude of geographic coordinates are used to match oceanic areas and economic sea areas. You can plot the distribution map with dotplot() function. Please refer to Flanders Marine Institute (2020) <doi:10.14284/403>. |
| License: | GPL-2 | GPL-3 [expanded from: GPL (≥ 2)] |
| Depends: | R (≥ 3.5.0) |
| Imports: | sf, broom, ggplot2, maps, methods |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.3 |
| LazyData: | true |
| Collate: | 'idfocean.R' 'idfeez.R' 'data.R' 'dotplot.R' |
| NeedsCompilation: | no |
| Packaged: | 2026-04-21 08:53:51 UTC; chihhao |
| Repository: | CRAN |
| Date/Publication: | 2026-04-21 11:02:17 UTC |
dotplot
Description
This function allows you to draw data distribution geographically from a numeric vector.
Usage
dotplot(
lona,
lata,
map = "ALL",
grid = FALSE,
color = "#FF0000",
size = 1,
shape = 16
)
Arguments
lona |
Input the longitude. |
lata |
Input the latitude. |
map |
default is "ALL", Other possible options is "PAC", "IND" and "ATL". |
grid |
default is FALSE, when TRUE show the 5 degree grid. |
color |
default is "#FF0000", define the color of points. |
size |
default is 1, define the size of points. |
shape |
default is 16, define the shape of points. |
Value
the plot of lona and lata.
Examples
dotplot(141,23)
Exclusive Economic Zones (EEZ)
Description
A spatial dataset containing the boundaries of Exclusive Economic Zones.
Usage
eez_rg
Format
eez_rg is an sf object with 16 variables:
- OBJECTID
Internal identifier
- EEZ
Name of the EEZ area
- Country
Country name
- ID
Identifier
- Sovereign
Sovereign state
- Remarks
Additional remarks
- Sov_ID
Sovereign ID
- EEZ_ID
EEZ ID
- ISO_3digit
ISO 3-digit country code
- MRGID
Marine Regions Gazetteer Identifier
- Date_chang
Date of change
- Area_m2
Area in square meters
- Longitude
Longitude of centroid
- Latitude
Latitude of centroid
- MRGID_EEZ
EEZ MRGID
- geometry
Spatial geometry
Flanders Marine Institute (2020). MarineRegions.org. <doi:10.14284/403>
idfeez
Description
This function allows you to identify location in which EEZ from a numeric vector.
Usage
idfeez(lon, lat, ac = TRUE)
Arguments
lon |
A numeric vector of longitudes. |
lat |
A numeric vector of latitudes. |
ac |
logical. If |
Examples
idfeez(141,23)
idfocean
Description
Return The Pacific Ocean(PAC), Indian Ocean(IND) or Atlantic Ocean(ATL) of your coordinate.
Usage
idfocean(lon, lat)
Arguments
lon |
A numeric vector of longitudes. |
lat |
A numeric vector of latitudes. |
Value
A character vector of the ocean ("PAC", "IND", "ATL", or "-") for each coordinate.
Examples
idfocean(125,20)
idfocean(c(125, 40), c(20, -10))